==> zio-aws-dynamodb_3-5.17.121.3-sources.jar: zio/aws/dynamodb/model/ExportTableToPointInTimeResponse.scala <==
package zio.aws.dynamodb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ExportTableToPointInTimeResponse(
    exportDescription: Option[zio.aws.dynamodb.model.ExportDescription] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.dynamodb.model.ExportTableToPointInTimeResponse = {
    import ExportTableToPointInTimeResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.dynamodb.model.ExportTableToPointInTimeResponse
      .builder()
      .optionallyWith(exportDescription.map(value => value.buildAwsValue()))(
        _.exportDescription
      )
      .build()
  }
  def asReadOnly
      : zio.aws.dynamodb.model.ExportTableToPointInTimeResponse.ReadOnly =
    zio.aws.dynamodb.model.ExportTableToPointInTimeResponse
      .wrap(buildAwsValue())
}
object ExportTableToPointInTimeResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.dynamodb.model.ExportTableToPointInTimeResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.dynamodb.model.ExportTableToPointInTimeResponse =
      zio.aws.dynamodb.model.ExportTableToPointInTimeResponse(
        exportDescription.map(value => value.asEditable)
      )
    def exportDescription
        : Option[zio.aws.dynamodb.model.ExportDescription.ReadOnly]
    def getExportDescription: ZIO[
      Any,
      AwsError,
      zio.aws.dynamodb.model.ExportDescription.ReadOnly
    ] = AwsError.unwrapOptionField("exportDescription", exportDescription)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.dynamodb.model.ExportTableToPointInTimeResponse
  ) extends zio.aws.dynamodb.model.ExportTableToPointInTimeResponse.ReadOnly {
    override val exportDescription
        : Option[zio.aws.dynamodb.model.ExportDescription.ReadOnly] = scala
      .Option(impl.exportDescription())
      .map(value => zio.aws.dynamodb.model.ExportDescription.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.dynamodb.model.ExportTableToPointInTimeResponse
  ): zio.aws.dynamodb.model.ExportTableToPointInTimeResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-dynamodb_3-7.21.15.11-sources.jar: zio/aws/dynamodb/model/ExportTableToPointInTimeResponse.scala <==
package zio.aws.dynamodb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ExportTableToPointInTimeResponse(
    exportDescription: Optional[zio.aws.dynamodb.model.ExportDescription] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.dynamodb.model.ExportTableToPointInTimeResponse = {
    import ExportTableToPointInTimeResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.dynamodb.model.ExportTableToPointInTimeResponse
      .builder()
      .optionallyWith(exportDescription.map(value => value.buildAwsValue()))(
        _.exportDescription
      )
      .build()
  }
  def asReadOnly
      : zio.aws.dynamodb.model.ExportTableToPointInTimeResponse.ReadOnly =
    zio.aws.dynamodb.model.ExportTableToPointInTimeResponse
      .wrap(buildAwsValue())
}
object ExportTableToPointInTimeResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.dynamodb.model.ExportTableToPointInTimeResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.dynamodb.model.ExportTableToPointInTimeResponse =
      zio.aws.dynamodb.model.ExportTableToPointInTimeResponse(
        exportDescription.map(value => value.asEditable)
      )
    def exportDescription
        : Optional[zio.aws.dynamodb.model.ExportDescription.ReadOnly]
    def getExportDescription: ZIO[
      Any,
      AwsError,
      zio.aws.dynamodb.model.ExportDescription.ReadOnly
    ] = AwsError.unwrapOptionField("exportDescription", exportDescription)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.dynamodb.model.ExportTableToPointInTimeResponse
  ) extends zio.aws.dynamodb.model.ExportTableToPointInTimeResponse.ReadOnly {
    override val exportDescription
        : Optional[zio.aws.dynamodb.model.ExportDescription.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.exportDescription())
        .map(value => zio.aws.dynamodb.model.ExportDescription.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.dynamodb.model.ExportTableToPointInTimeResponse
  ): zio.aws.dynamodb.model.ExportTableToPointInTimeResponse.ReadOnly =
    new Wrapper(impl)
}
